@@ -3,8 +3,6 @@ import typing
 import bl_ui.space_toolsystem_common
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class IMAGE_PT_tools_active(
         bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
@@ -1053,9 +1051,6 @@ class _defs_edit_mesh:
     bisect = None
     ''' '''
 
-    cube_add = None
-    ''' '''
-
     edge_slide = None
     ''' '''
 
@@ -1068,6 +1063,9 @@ class _defs_edit_mesh:
     extrude_individual = None
     ''' '''
 
+    extrude_manifold = None
+    ''' '''
+
     extrude_normals = None
     ''' '''
 
@@ -1237,6 +1235,11 @@ class _defs_image_generic:
         pass
 
 
+class _defs_image_uv_edit:
+    rip_region = None
+    ''' '''
+
+
 class _defs_image_uv_sculpt:
     def generate_from_brushes(self, context):
         ''' 
@@ -1312,12 +1315,21 @@ class _defs_pose:
 
 
 class _defs_sculpt:
+    cloth_filter = None
+    ''' '''
+
+    color_filter = None
+    ''' '''
+
     hide_border = None
     ''' '''
 
     mask_border = None
     ''' '''
 
+    mask_by_color = None
+    ''' '''
+
     mask_lasso = None
     ''' '''
 
@@ -1395,6 +1407,29 @@ class _defs_vertex_paint:
         pass
 
 
+class _defs_view3d_add:
+    cone_add = None
+    ''' '''
+
+    cube_add = None
+    ''' '''
+
+    cylinder_add = None
+    ''' '''
+
+    ico_sphere_add = None
+    ''' '''
+
+    uv_sphere_add = None
+    ''' '''
+
+    def draw_settings_interactive_add(self, layout, tool):
+        ''' 
+
+        '''
+        pass
+
+
 class _defs_view3d_generic:
     cursor = None
     ''' '''
@@ -1458,7 +1493,7 @@ class _template_widget:
 
 
 def generate_from_enum_ex(_context, idname_prefix, icon_prefix, type, attr,
-                          cursor, tooldef_keywords):
+                          cursor, tooldef_keywords, exclude_filter):
     ''' 
 
     '''
