@@ -282,10 +282,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: typing.Union['BMFace', 'BMEdge', 'BMVert'] = None
+    active: typing.Union['BMEdge', 'BMFace', 'BMVert'] = None
     ''' The last selected element or None (read-only).
 
-    :type: typing.Union['BMFace', 'BMEdge', 'BMVert']
+    :type: typing.Union['BMEdge', 'BMFace', 'BMVert']
     '''
 
     def add(self, element):
