@@ -1,7 +1,5 @@
 import sys
 import typing
-
-GenericType = typing.TypeVar("GenericType")
 depsgraph_update_post = None
 ''' on depsgraph update (post)
 '''
@@ -11,11 +9,11 @@ depsgraph_update_pre = None
 '''
 
 frame_change_post = None
-''' on frame change for playback and rendering (after)
+''' Called after frame change for playback and rendering, after the data has been evaluated for the new frame.
 '''
 
 frame_change_pre = None
-''' on frame change for playback and rendering (before)
+''' Called after frame change for playback and rendering, before any data is evaluated for the new frame. This makes it possible to change data and relations (for example swap an object to another mesh) for the new frame. Note that this handler is **not** to be used as 'before the frame changes' event. The dependency graph is not available in this handler, as data and relations may have been altered and the dependency graph has not yet been updated for that.
 '''
 
 load_factory_preferences_post = None
