@@ -7,8 +7,10 @@ import bpy.types
 def add_and_link_node(
         type: str = "",
         use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None,
+        settings: typing.
+        Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+              List['bl_operators.node.NodeSetting'],
+              'bpy_prop_collection'] = None,
         link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
@@ -17,7 +19,7 @@ def add_and_link_node(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     :param link_socket_index: Link Socket Index, Index of the socket to link
     :type link_socket_index: int
     '''
@@ -117,11 +119,12 @@ def add_mask(name: str = "Mask"):
     pass
 
 
-def add_node(
-        type: str = "",
-        use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None):
+def add_node(type: str = "",
+             use_transform: bool = False,
+             settings: typing.
+             Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+                   List['bl_operators.node.NodeSetting'],
+                   'bpy_prop_collection'] = None):
     ''' Add a node to the active tree
 
     :param type: Node Type, Node type
@@ -129,19 +132,20 @@ def add_node(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     '''
 
     pass
 
 
-def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                   'bpy_prop_collection'] = None,
+def add_reroute(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                 cursor: int = 8):
     ''' Add a reroute node
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -149,12 +153,13 @@ def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def add_search(
-        type: str = "",
-        use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None,
-        node_item: typing.Union[int, str] = ''):
+def add_search(type: str = "",
+               use_transform: bool = False,
+               settings: typing.
+               Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+                     List['bl_operators.node.NodeSetting'],
+                     'bpy_prop_collection'] = None,
+               node_item: typing.Union[int, str] = ''):
     ''' Add a node to the active tree
 
     :param type: Node Type, Node type
@@ -162,7 +167,7 @@ def add_search(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     :param node_item: Node Type, Node type
     :type node_item: typing.Union[int, str]
     '''
@@ -237,7 +242,7 @@ def clipboard_paste():
 
 
 def collapse_hide_unused_toggle():
-    ''' Toggle collapsed nodes and hide unused sockets
+    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py\:267 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$267> _
 
     '''
 
@@ -442,13 +447,14 @@ def link_viewer():
     pass
 
 
-def links_cut(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                 'bpy_prop_collection'] = None,
+def links_cut(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
               cursor: int = 12):
     ''' Use the mouse to cut (remove) some links
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -706,16 +712,18 @@ def select_grouped(extend: bool = False,
     pass
 
 
-def select_lasso(tweak: bool = False,
-                 path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'SET'):
+def select_lasso(
+        tweak: bool = False,
+        path: typing.Union[
+            typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+            List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+        mode: typing.Union[int, str] = 'SET'):
     ''' Select nodes using lasso selection
 
     :param tweak: Tweak, Only activate when mouse is not over a node - useful for tweak gesture
     :type tweak: bool
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
     :type mode: typing.Union[int, str]
     '''
@@ -802,7 +810,7 @@ def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
 
 
 def tree_path_parent():
-    ''' Go to parent node tree
+    ''' Go to parent node tree :file: startup/bl_operators/node.py\:297 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$297> _
 
     '''
 
