@@ -3,15 +3,15 @@ import typing
 import bpy.types
 
 
-def brush_stroke(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        mode: typing.Union[int, str] = 'NORMAL',
-        ignore_background_click: bool = False):
+def brush_stroke(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                 mode: typing.Union[int, str] = 'NORMAL',
+                 ignore_background_click: bool = False):
     ''' Sculpt a stroke into the geometry
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Regular, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
     :type mode: typing.Union[int, str]
     :param ignore_background_click: Ignore Background Click, Clicks on the background do not start the stroke
@@ -28,7 +28,7 @@ def cloth_filter(type: typing.Union[int, str] = 'GRAVITY',
                  use_face_sets: bool = False):
     ''' Applies a cloth simulation deformation to the entire mesh
 
-    :param type: Filter type, Operation that is going to be applied to the mesh * GRAVITY Gravity, Applies gravity to the simulation. * INFLATE Inflate, Inflates the cloth. * EXPAND Expand, Expands the cloth's dimensions. * PINCH Pinch, Pinches the cloth to the point were the cursor was when the filter started.
+    :param type: Filter type, Operation that is going to be applied to the mesh * GRAVITY Gravity, Applies gravity to the simulation. * INFLATE Inflate, Inflates the cloth. * EXPAND Expand, Expands the cloth's dimensions. * PINCH Pinch, Pinches the cloth to the point where the cursor was when the filter started.
     :type type: typing.Union[int, str]
     :param strength: Strength, Filter Strength
     :type strength: float
