@@ -239,37 +239,38 @@ def alembic_import(filepath: str = "",
     pass
 
 
-def append(
-        filepath: str = "",
-        directory: str = "",
-        filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
-        filter_blender: bool = True,
-        filter_backup: bool = False,
-        filter_image: bool = False,
-        filter_movie: bool = False,
-        filter_python: bool = False,
-        filter_font: bool = False,
-        filter_sound: bool = False,
-        filter_text: bool = False,
-        filter_archive: bool = False,
-        filter_btx: bool = False,
-        filter_collada: bool = False,
-        filter_alembic: bool = False,
-        filter_usd: bool = False,
-        filter_volume: bool = False,
-        filter_folder: bool = True,
-        filter_blenlib: bool = True,
-        filemode: int = 1,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
-        link: bool = False,
-        autoselect: bool = True,
-        active_collection: bool = True,
-        instance_collections: bool = False,
-        set_fake: bool = False,
-        use_recursive: bool = True):
+def append(filepath: str = "",
+           directory: str = "",
+           filename: str = "",
+           files: typing.
+           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+                 List['bpy.types.OperatorFileListElement'],
+                 'bpy_prop_collection'] = None,
+           filter_blender: bool = True,
+           filter_backup: bool = False,
+           filter_image: bool = False,
+           filter_movie: bool = False,
+           filter_python: bool = False,
+           filter_font: bool = False,
+           filter_sound: bool = False,
+           filter_text: bool = False,
+           filter_archive: bool = False,
+           filter_btx: bool = False,
+           filter_collada: bool = False,
+           filter_alembic: bool = False,
+           filter_usd: bool = False,
+           filter_volume: bool = False,
+           filter_folder: bool = True,
+           filter_blenlib: bool = True,
+           filemode: int = 1,
+           display_type: typing.Union[int, str] = 'DEFAULT',
+           sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+           link: bool = False,
+           autoselect: bool = True,
+           active_collection: bool = True,
+           instance_collections: bool = False,
+           set_fake: bool = False,
+           use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -279,7 +280,7 @@ def append(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -338,8 +339,10 @@ def append(
 def batch_rename(
         data_type: typing.Union[int, str] = 'OBJECT',
         data_source: typing.Union[int, str] = 'SELECT',
-        actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'],
-                              'bpy_prop_collection'] = None):
+        actions: typing.
+        Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.
+              List['bl_operators.wm.BatchRenameAction'],
+              'bpy_prop_collection'] = None):
     ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param data_type: Type, Type of data to rename
@@ -347,14 +350,14 @@ def batch_rename(
     :param data_source: Source
     :type data_source: typing.Union[int, str]
     :param actions: actions
-    :type actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
+    :type actions: typing.Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
     '''
 
     pass
 
 
 def blend_strings_utf8_validate():
-    ''' Check and fix all strings in current .blend file to be valid UTF-8 Unicode (needed for some old, 2.4x area files)
+    ''' Check and fix all strings in current .blend file to be valid UTF-8 Unicode (needed for some old, 2.4x area files) :file: startup/bl_operators/file.py\:294 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/file.py$294> _
 
     '''
 
@@ -1067,8 +1070,10 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         hide_props_region: bool = True,
         filter_blender: bool = True,
         filter_backup: bool = False,
@@ -1101,7 +1106,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
     :param filter_blender: Filter .blend files
@@ -1152,8 +1157,10 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1187,7 +1194,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1332,7 +1339,7 @@ def open_mainfile(filepath: str = "",
 
 
 def operator_cheat_sheet():
-    ''' List all the Operators in a text-block, useful for scripting
+    ''' List all the Operators in a text-block, useful for scripting :file: startup/bl_operators/wm.py\:1612 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1612> _
 
     '''
 
@@ -1409,8 +1416,10 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1423,7 +1432,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1448,8 +1457,10 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1462,7 +1473,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -2075,7 +2086,7 @@ def tool_set_by_index(index: int = 0,
 
 
 def toolbar():
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/wm.py\:1816 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1816> _
 
     '''
 
@@ -2083,7 +2094,7 @@ def toolbar():
 
 
 def toolbar_fallback_pie():
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/wm.py\:1840 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1840> _
 
     '''
 
@@ -2091,7 +2102,7 @@ def toolbar_fallback_pie():
 
 
 def toolbar_prompt():
-    ''' Leader key like functionality for accessing tools
+    ''' Leader key like functionality for accessing tools :file: startup/bl_operators/wm.py\:1940 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1940> _
 
     '''
 
