@@ -1,10 +1,10 @@
 import sys
 import typing
-from . import interpolate
-from . import kdtree
-from . import geometry
 from . import noise
+from . import kdtree
 from . import bvhtree
+from . import interpolate
+from . import geometry
 
 
 class Color:
@@ -788,7 +788,7 @@ class Quaternion:
         pass
 
     def to_exponential_map(self) -> 'Vector':
-        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations.
+        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations. To convert back to a quaternion, pass it to the Quaternion constructor.
 
         :rtype: 'Vector'
         :return: exponential map.
